==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebCircularGradientDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCircularGradientDescription } from "./WebCircularGradientDescription";
/**
 * @hidden
 */
var WebCircularGradientDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCircularGradientDescriptionMetadata, _super);
    function WebCircularGradientDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCircularGradientDescriptionMetadata.b = function (a) {
        if (WebCircularGradientDescriptionMetadata.a == null) {
            WebCircularGradientDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCircularGradientDescriptionMetadata.c(WebCircularGradientDescriptionMetadata.a);
        }
        if (a.g(WebCircularGradientDescriptionMetadata.a)) {
            return;
        }
        a.s(WebCircularGradientDescriptionMetadata.a);
    };
    WebCircularGradientDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CircularGradient");
        a.item("Offset", "String");
        a.item("Color", "String");
        a.item("Opacity", "Number:double");
    };
    WebCircularGradientDescriptionMetadata.d = function (a) {
        WebCircularGradientDescriptionMetadata.b(a);
        a.u("WebCircularGradient", function () { return new WebCircularGradientDescription(); });
        a.t("WebCircularGradient", WebCircularGradientDescriptionMetadata.a);
    };
    WebCircularGradientDescriptionMetadata.$t = markType(WebCircularGradientDescriptionMetadata, 'WebCircularGradientDescriptionMetadata');
    WebCircularGradientDescriptionMetadata.a = null;
    return WebCircularGradientDescriptionMetadata;
}(Base));
export { WebCircularGradientDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebCircularGradientDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCircularGradientDescription } from "./WebCircularGradientDescription";
/**
 * @hidden
 */
var WebCircularGradientDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCircularGradientDescriptionMetadata, _super);
    function WebCircularGradientDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCircularGradientDescriptionMetadata.b = function (a) {
        if (WebCircularGradientDescriptionMetadata.a == null) {
            WebCircularGradientDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCircularGradientDescriptionMetadata.c(WebCircularGradientDescriptionMetadata.a);
        }
        if (a.j(WebCircularGradientDescriptionMetadata.a)) {
            return;
        }
        a.y(WebCircularGradientDescriptionMetadata.a);
    };
    WebCircularGradientDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CircularGradient");
        a.item("__tagNameWC", "String:igc-circular-gradient");
        a.item("Offset", "String");
        a.item("Color", "String");
        a.item("Opacity", "Number:double");
    };
    WebCircularGradientDescriptionMetadata.d = function (a) {
        WebCircularGradientDescriptionMetadata.b(a);
        a.aa("WebCircularGradient", function () { return new WebCircularGradientDescription(); });
        a.z("WebCircularGradient", WebCircularGradientDescriptionMetadata.a);
    };
    WebCircularGradientDescriptionMetadata.$t = markType(WebCircularGradientDescriptionMetadata, 'WebCircularGradientDescriptionMetadata');
    WebCircularGradientDescriptionMetadata.a = null;
    return WebCircularGradientDescriptionMetadata;
}(Base));
export { WebCircularGradientDescriptionMetadata };
